[Ffmpeg-cvslog] r8602 - in trunk/libavcodec: rle.c rle.h targaenc.c

michael subversion
Tue Apr 3 08:40:26 CEST 2007


Author: michael
Date: Tue Apr  3 08:40:21 2007
New Revision: 8602

Modified:
   trunk/libavcodec/rle.c
   trunk/libavcodec/rle.h
   trunk/libavcodec/targaenc.c

Log:
Changed the rle encoder a little and made it more universal.
Not only the repeated byte is calculated as (count ^ xor) + add
but also the raw encoding lenth byte is calculated as that too
patch by Xiaohui Sun sunxiaohui  dsp ac cn


Modified: trunk/libavcodec/rle.c
==============================================================================
--- trunk/libavcodec/rle.c	(original)
+++ trunk/libavcodec/rle.c	Tue Apr  3 08:40:21 2007
@@ -55,7 +55,8 @@ static int count_pixels(const uint8_t *s
     return count;
 }
 
-int ff_rle_encode(uint8_t *outbuf, int out_size, const uint8_t *ptr , int bpp, int w, int8_t add, uint8_t xor)
+int ff_rle_encode(uint8_t *outbuf, int out_size, const uint8_t *ptr , int bpp, int w,
+                   int8_t add_rep, uint8_t xor_rep,int8_t add_raw,uint8_t xor_raw)
 {
     int count, x;
     uint8_t *out = outbuf;
@@ -64,13 +65,13 @@ int ff_rle_encode(uint8_t *outbuf, int o
         /* see if we can encode the next set of pixels with RLE */
         if((count = count_pixels(ptr, w-x, bpp, 1)) > 1) {
             if(out + bpp + 1 > outbuf + out_size) return -1;
-            *out++ = (count ^ xor) + add;
+            *out++ = (count ^ xor_rep) + add_rep;
             memcpy(out, ptr, bpp);
             out += bpp;
         } else {
             /* fall back on uncompressed */
             count = count_pixels(ptr, w-x, bpp, 0);
-            *out++ = count - 1;
+            *out++ = (count ^ xor_raw) + add_raw;
 
             if(out + bpp*count > outbuf + out_size) return -1;
             memcpy(out, ptr, bpp * count);

Modified: trunk/libavcodec/rle.h
==============================================================================
--- trunk/libavcodec/targaenc.c	(original)
+++ trunk/libavcodec/targaenc.c	Tue Apr  3 08:40:21 2007
@@ -41,7 +41,7 @@ static int targa_encode_rle(uint8_t *out
     out = outbuf;
 
     for(y = 0; y < h; y ++) {
-        ret = ff_rle_encode(out, out_size, pic->data[0] + pic->linesize[0] * y, bpp, w, 0x7f, 0);
+        ret = ff_rle_encode(out, out_size, pic->data[0] + pic->linesize[0] * y, bpp, w, 0x7f, 0, -1, 0);
         if(ret == -1){
             return -1;
         }




More information about the ffmpeg-cvslog mailing list
--- trunk/libavcodec/rle.h	(original)
+++ trunk/libavcodec/rle.h	Tue Apr  3 08:40:21 2007
@@ -23,7 +23,8 @@
 #define RLE_H
 
 /**
  * RLE compress the row, with maximum size of out_size. Value before repeated bytes is (count ^ xor) + add.
  * @param outbuf Output buffer
  * @param out_size Maximum output size
  * @param ptr Input buffer
@@ -31,6 +32,7 @@
  * @param w Image width
  * @return Size of output in bytes, or -1 if larger than out_size
  */
-int ff_rle_encode(uint8_t *outbuf, int out_size, const uint8_t *inbuf, int bpp, int w, int8_t add, uint8_t xor);
+int ff_rle_encode(uint8_t *outbuf, int out_size, const uint8_t *inbuf, int bpp, int w,
+                 int8_t add_rep, uint8_t xor_rep, int8_t add_raw, uint8_t xor_raw);
 
 #endif /* RLE_H */
@@ -23,7 +23,8 @@
 
 /**
- * RLE compress the row, with maximum size of out_size. Value before repeated bytes is (count ^ xor) + add.
+ * RLE compress the row, with maximum size of out_size. Value before repeated bytes is (count ^ xor_rep) + add_rep.
+ *                                                      Value before raw bytes is      (count ^ xor_raw) + add_raw.
  * @param outbuf Output buffer
  * @param out_size Maximum output size

Modified: trunk/libavcodec/targaenc.c
==============================================================================